@@ -23,11 +23,12 @@ class Client(object):
             return factory.MultipartSignedRequestFactory
         return factory.SignedRequestFactory
 
-    def _get_response(self, http_method, endpoint, data=None, files=None, timeout=60,  **request_kwargs):
-        if request_kwargs.get("headers", {}).get("Content-Type") == "application/json":
+    def _get_response(self, http_method, endpoint, data=None, files=None, **request_kwargs):
+        headers = request_kwargs.get("headers", {})
+        if not isinstance(data, basestring) and headers.get("Content-Type") == "application/json":
             data = json.dumps(data, default=json_encoder)
         try:
-            http_response = urllib2.urlopen(self._get_request(http_method, endpoint, data, files, **request_kwargs), timeout=timeout)
+            http_response = urllib2.urlopen(self._get_request(http_method, endpoint, data, files, **request_kwargs))
         except urllib2.HTTPError as e:
             http_response = e
         return response.Response(http_response)
