@@ -39,7 +39,20 @@ class ClientTests(unittest.TestCase):
     def test_get_response_invokes_urlopen_with_request_return_value(self):
         with mock.patch.object(self.sut_class, '_get_request') as get_request:
             self.sut._get_response('GET', '/', {}, **{})
-        self.urlopen.assert_called_once_with(get_request.return_value, timeout=60)
+        self.urlopen.assert_called_once_with(get_request.return_value)
+
+    def test_get_response_encodes_json_data_when_content_type_is_application_json(self):
+        request_args = {"headers": {"Content-Type": "application/json"}}
+        with mock.patch.object(self.sut_class, '_get_request') as get_request:
+            self.sut._get_response('POST', '/endpoint', {'some': 'data'}, **request_args)
+        get_request.assert_called_once_with('POST', '/endpoint', '{"some": "data"}', None, **request_args)
+
+    def test_get_response_does_not_encode_json_data_when_json_content_already_a_string(self):
+        request_args = {"headers": {"Content-Type": "application/json"}}
+        json_data = '{"some": "data"}'
+        with mock.patch.object(self.sut_class, '_get_request') as get_request:
+            self.sut._get_response('POST', '/endpoint', json_data, **request_args)
+        get_request.assert_called_once_with('POST', '/endpoint', json_data, None, **request_args)
 
     def test_get_response_invokes_get_request_incoming_params(self):
         method = 'GET'
@@ -67,18 +80,6 @@ class ClientTests(unittest.TestCase):
             result = self.sut._get_response('GET', '/', {}, **{})
         self.assertEqual(result, self.response.return_value)
 
-    @mock.patch('urllib2.urlopen')
-    @mock.patch.object(client.Client, '_get_request')
-    def test_get_response_passes_default_timeout_to_url_open(self, get_request, urlopen):
-        self.sut._get_response('GET', '/', {}, **{})
-        urlopen.assert_called_once_with(get_request.return_value, timeout=60)
-
-    @mock.patch('urllib2.urlopen')
-    @mock.patch.object(client.Client, '_get_request')
-    def test_get_response_passes_passed_timeout_to_url_open(self, get_request, urlopen):
-        self.sut._get_response('GET', '/', {}, **{'timeout': 20})
-        urlopen.assert_called_once_with(get_request.return_value, timeout=20)
-
     def test_get_request_instantiates_factory_with_params(self):
         with mock.patch('generic_request_signer.factory.SignedRequestFactory') as factory:
             self.sut._get_request('GET', '/', {}, **{})
